@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Adapter::Syslog;
 
 # ABSTRACT: Send Log::Any logs to syslog
-our $VERSION = '1.700';
+our $VERSION = '1.701';
 
 use Log::Any::Adapter::Util qw{make_method};
 use base qw{Log::Any::Adapter::Base};
@@ -99,11 +99,11 @@ foreach my $method (Log::Any->logging_methods()) {
         warn      => "warning",
         error     => "err",
         err       => "err",
-        critical  => "critical",
-        crit      => "critical",
-        fatal     => "critical",
+        critical  => "crit",
+        crit      => "crit",
+        fatal     => "crit",
         alert     => "alert",
-        emergency => "emergency",
+        emergency => "emerg",
     }->{$method};
     defined($priority) or $priority = "error"; # unknown, take a guess.
 
@@ -141,7 +141,7 @@ Log::Any::Adapter::Syslog - Send Log::Any logs to syslog
 
 =head1 VERSION
 
-version 1.700
+version 1.701
 
 =head1 SYNOPSIS
 
